@@ -1,8 +1,8 @@
 #' @name lp_nl_iv
 #' @title Compute nonlinear impulse responses with identified shock
 #' @description Compute nonlinear impulse responses with local projections and identified shock.
-#' The data are separated into two states via a smooth transition
-#' function as applied in Auerbach and Gorodnichenko (2012).
+#' The data can be separated into two states by a smooth transition function as applied in Auerbach and Gorodnichenko (2012),
+#' or by a simple dummy approach.
 #' @param endog_data A \link{data.frame}, containing all endogenous variables for the VAR.
 #' @param lags_endog_nl NaN or integer. NaN if lags are chosen by a lag length criterion. Integer for number of lags for \emph{endog_data}.
 #' @param shock One column \link{data.frame}, including the instrument to shock with.
@@ -28,7 +28,10 @@
 #'               The data for the two regimes are: \cr
 #'               Regime 1 = (1-\eqn{F(z_{t-1})})*y_{(t-p)}, \cr
 #'               Regime 2 = \eqn{F(z_{t-1})}*y_{(t-p)}.
+#'@param lag_switching Boolean. Use the first lag of the values of the transition function? TRUE (default) or FALSE.
 #'@param gamma Double. Positive number which is used in the transition function.
+#'@param use_logistic Boolean. Use logistic function to separate states? TRUE (default) or FALSE. If FALSE, the values of the switching variable
+#'                     have to be binary (0/1).
 #'@param use_hp Boolean. Use HP-filter? TRUE or FALSE.
 #'@param lambda Double. Value of \eqn{\lambda} for the Hodrick-Prescott filter (if use_hp = TRUE).
 #'@param num_cores Integer. The number of cores to use for the estimation. If NULL, the function will
@@ -131,20 +134,12 @@
 #'                            shock             = shock,
 #'                            exog_data         = exog_data,
 #'                            lags_exog         = 4,
-#'                            contemp_data      = NULL,
-#'                            lags_criterion    = NaN,
-#'                            max_lags          = NaN,
 #'                            trend             = 0,
 #'                            confint           = 1.96,
 #'                            hor               = 20,
 #'                            switching         = switching_variable,
-#'                            use_hp            = 0,
-#'                            lambda            = NaN, # Ravn and Uhlig (2002):
-#'                                                     # Annual data    = 6.25
-#'                                                     # Quarterly data = 1600
-#'                                                     # Monthly data   = 129,600
-#'                            gamma             = 3,
-#'                            num_cores         = NULL)
+#'                            use_hp            = FALSE,
+#'                            gamma             = 3)
 #'
 #'# Make and save plots
 #'  plots_nl_iv <- plot_nl(results_nl_iv)
@@ -179,12 +174,14 @@ lp_nl_iv <- function(endog_data,
                             exog_data         = NULL,
                             lags_exog         = NULL,
                             contemp_data      = NULL,
-                            lags_criterion    = NULL,
-                            max_lags          = NULL,
+                            lags_criterion    = NaN,
+                            max_lags          = NaN,
                             trend             = NULL,
                             confint           = NULL,
                             hor               = NULL,
                             switching         = NULL,
+                            lag_switching     = TRUE,
+                            use_logistic      = TRUE,
                             use_hp            = NULL,
                             lambda            = NULL,
                             gamma             = NULL,
@@ -211,17 +208,6 @@ lp_nl_iv <- function(endog_data,
     stop('The exogenous data with contemporary impact has to be a data.frame.')
   }
 
-  # Give message when no linear model is provided
-  if(is.null(exog_data)){
-    message('You estimate the model without exogenous data.')
-  }
-
-  # Give message when no contemporaneous data is provided
-  if(is.null(contemp_data)){
-    message('You estimate the model without exogenous data with contemporaneous impact')
-  }
-
-
 
   # Check whether 'trend' is given
   if(is.null(trend) == TRUE){
@@ -251,7 +237,7 @@ lp_nl_iv <- function(endog_data,
   }
 
   # Check whether 'gamma' is given
-  if(is.null(gamma) == TRUE){
+  if(isTRUE(use_logistic) & is.null(gamma) == TRUE){
     stop('Please specify gamma for the transition function.')
   }
 
@@ -299,10 +285,10 @@ lp_nl_iv <- function(endog_data,
   }
 
   # Create list to store inputs
-  specs <- list()
+    specs <- list()
 
   # Specify inputs
-  specs$lags_endog_nl               <- lags_endog_nl
+   specs$lags_endog_nl               <- lags_endog_nl
 
   if(is.data.frame(shock)){
      specs$shock   <- shock  }  else {
@@ -327,6 +313,8 @@ lp_nl_iv <- function(endog_data,
     specs$confint        <- confint
     specs$hor            <- hor
     specs$switching      <- switching
+    specs$lag_switching  <- lag_switching
+    specs$use_logistic   <- use_logistic
     specs$use_hp         <- use_hp
     specs$lambda         <- lambda
     specs$gamma          <- gamma
