@@ -19,7 +19,7 @@ plot_lin <- function(results_lin){
   irf_lin_up   <- results_lin[[3]]
 
 
-  specs        <- results_lin[[4]]
+  specs        <- results_lin$specs
 
   # Plots for lin function
   if(specs$model_type == 0){
@@ -60,7 +60,7 @@ plot_lin <- function(results_lin){
  }
 }
 
-         } else if(specs$model_type == 1){
+         } else if(specs$model_type == 1| specs$model_type == 2){
 
       gg_lin       <- rep(list(NaN), specs$endog)
 
